@@ -1,7 +1,7 @@
 param.gam <- function(object, num = NULL, bootstrap = FALSE) {
   if (!bootstrap) {
     coef <- mvrnorm(num, mu=coef(object), Sigma=vcov(object))
-    if (getzelig(object) == "gam.normal") {
+    if (getzelig(object) == "normal.gam") {
       df <- object$df.residual
       sig2 <- summary(object)$dispersion
       alpha <- sqrt(df*sig2/rchisq(num, df=df))
